/** 
 * \file IndependenceNumber.h
 *  
 * \brief Implemention of a simple algorithm to calculate the
 * Independence Number of a fullerene graph (using its complement
 * to find the size of a maximum clique, with the help of the MaxCliqueDyn
 * algorithm by Janez Konc and Dusanka Janezic)
 *
 * \author
 * Thiago Henrique de Araujo Lemos \n
 * Universidade Federal do Paraná, \n
 * Departamento de Informatica, \n
 * thalemos at inf (dot) ufpr (dot) br
 *
 * \version 1.0
 * \date May 2014
 *
 * \attention This program is distributed WITHOUT ANY WARRANTY, and it
 *            may be freely redistributed under the condition that the
 *            copyright notices  are not removed,  and no compensation
 *            is received. Private, research, and institutional use is
 *            free. Distribution of this  code as part of a commercial
 *            system  is permissible ONLY  BY DIRECT  ARRANGEMENT WITH
 *            THE AUTHOR.
 */
 
#ifndef _INDEPENDENCE_NUMBER_H_
#define _INDEPENDENCE_NUMBER_H_


//#include <cassert>                          // assert
#include "mcqd.h"                           // m.mcq(qmax, qsize)

using namespace std;


// ------------------------------------------------------------------
//
// Implementation starts here.
//
// ------------------------------------------------------------------

/**
 * \fn int independenceNumber(bool** a, int n)
 *
 * \brief Implementation of a simple algorithm to calculate the Independence
 * Number of a given fullerene graph, using the adjacency matrix of its complement
 * to find the size of a maximum clique.
 *
 * \param a The adjacency matrix of the complement of a fullerene graph.
 *
 * \return The independence number of the given fullerene graph.
 */
int independenceNumber(bool** a, int n) {
    Maxclique m(a, n);
    int* qmax;
    int  qsize;
    m.mcqdyn(qmax, qsize);
    delete[] qmax;
    return qsize;
}

#endif // _INDEPENDENCE_NUMBER_H_
